package com.ningdatech.pmapi.projectCollection;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.google.common.collect.Lists;
import com.ningdatech.pmapi.AppTests;
import com.ningdatech.pmapi.common.constant.BizConst;
import com.ningdatech.pmapi.gov.model.dto.GovBizProjectApplyDTO;
import com.ningdatech.pmapi.gov.model.dto.GovBizProjectBaseinfoDTO;
import com.ningdatech.pmapi.gov.model.dto.GovBizProjectSaveDTO;
import com.ningdatech.pmapi.gov.model.entity.*;
import com.ningdatech.pmapi.gov.service.*;
import com.ningdatech.pmapi.projectdeclared.utils.GenerateProjectCodeUtil;
import com.ningdatech.pmapi.scheduler.task.SynProjectCollectionTask;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;

import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.List;

/**
 * @Classname ProjectCollectionTest
 * @Description
 * @Date 2023/9/7 15:08
 * @Author PoffyZhang
 */
public class ProjectCollectionTest extends AppTests {

    @Autowired
    private IGovBizProjectBaseinfoService baseinfoService;

    @Autowired
    private IGovBizProjectApplyService applyService;

    @Autowired
    private IGovBizProjectApproveService approveService;

    @Autowired
    private IGovBizProjectCimplementService cimplementService;

    @Autowired
    private IGovBizProjectMimplementService mimplementService;

    @Autowired
    private IGovBizProjectProcureService procureService;

    @Autowired
    private GenerateProjectCodeUtil generateProjectCodeUtil;

    @Autowired
    private SynProjectCollectionTask collectionTask;

    @Test
    public void test(){
        List<String> baseProjIds = Lists.newArrayList("33110000020230100061");
        for(String baseProjId : baseProjIds){
            GovBizProjectBaseinfo baseinfo = baseinfoService.getOne(Wrappers.lambdaQuery(GovBizProjectBaseinfo.class)
                    .eq(GovBizProjectBaseinfo::getBaseProjId, baseProjId)
                    .last(BizConst.LIMIT_1));
            GovBizProjectApply apply = applyService.getOne(Wrappers.lambdaQuery(GovBizProjectApply.class)
                    .eq(GovBizProjectApply::getBaseProjId, baseProjId)
                    .last(BizConst.LIMIT_1));

            GovBizProjectSaveDTO saveDTO = new GovBizProjectSaveDTO();
            saveDTO.setApply(BeanUtil.copyProperties(apply, GovBizProjectApplyDTO.class));
            saveDTO.setBaseinfo(BeanUtil.copyProperties(baseinfo, GovBizProjectBaseinfoDTO.class));
            String newProjId = generateProjectCodeUtil.generateProjectCode(saveDTO);

            baseinfo.setBaseProjId(newProjId);
            baseinfoService.updateById(baseinfo);
            apply.setBaseProjId(newProjId);
            applyService.updateById(apply);
            approveService.update(Wrappers.lambdaUpdate(GovBizProjectApprove.class)
                    .eq(GovBizProjectApprove::getBaseProjId,baseProjId)
                    .set(GovBizProjectApprove::getBaseProjId,newProjId));
            cimplementService.update(Wrappers.lambdaUpdate(GovBizProjectCimplement.class)
                    .eq(GovBizProjectCimplement::getBaseProjId,baseProjId)
                    .set(GovBizProjectCimplement::getBaseProjId,newProjId));
            mimplementService.update(Wrappers.lambdaUpdate(GovBizProjectMimplement.class)
                    .eq(GovBizProjectMimplement::getBaseProjId,baseProjId)
                    .set(GovBizProjectMimplement::getBaseProjId,newProjId));
            procureService.update(Wrappers.lambdaUpdate(GovBizProjectProcure.class)
                    .eq(GovBizProjectProcure::getBaseProjId,baseProjId)
                    .set(GovBizProjectProcure::getBaseProjId,newProjId));
        }
    }

    @Test
    public void test2() throws UnknownHostException {
        collectionTask.doTask();
    }

    @Test
    public void test3() throws UnknownHostException {
        collectionTask.stagingConvertPdf("33112200020230100008");
    }
}
